import os
import logging
from logging.handlers import TimedRotatingFileHandler


def configure_logger(log_dir, debug, log_name):

    format_str = "%(asctime)s|%(message)s"

    logger = logging.getLogger("{}.log".format(log_name))
    logger.setLevel(logging.DEBUG if debug else logging.WARNING)
    logger.propagate = False

    if not log_dir:
        formatter = logging.Formatter(fmt=format_str)
        handler = logging.StreamHandler()
        handler.setFormatter(formatter)
        logger.addHandler(handler)
    else:
        if not os.path.exists(log_dir):
            os.makedirs(log_dir)

        logger_path = os.path.join(log_dir, "dox-scraper.{}.log".format(log_name))
        logger_handler = TimedRotatingFileHandler(logger_path, when="midnight")
        logger_formatter = logging.Formatter(format_str)
        logger_handler.setFormatter(logger_formatter)
        logger.addHandler(logger_handler)

    logger.info("dox-scraper {} started.".format(log_name))
