import time


def create_throttler(default_wait_secs=None):
    """Returns a function that when callled, will pause at least as long
    as the given argument before returning control.  For example, if
    given on second, and called twice, on the first call no pause
    will occur.  On the second call, the system will sleep so that at least
    one second has passed since the first call.
    """

    state = {
        "last_call": time.time()
    }

    def _(wait_secs=None):
        throttle_amount = wait_secs or default_wait_secs
        cur_time = time.time()
        sec_since_last_call = cur_time - state["last_call"]

        # If its been less than a second since we last called
        time_to_wait = None
        if sec_since_last_call < throttle_amount:
            time_to_wait = throttle_amount - sec_since_last_call
            time.sleep(time_to_wait)
            state["last_call"] = time.time()
        else:
            state["last_call"] = cur_time
    return _
