#!/usr/bin/env python

import collections
import argparse
import doxscrapers.sites
import doxscrapers.reporting
import doxscrapers.proxy
import doxscrapers.sites.pastebin
import doxscrapers.sites.cloudnine
import doxscrapers.sites.kdepaste
import doxscrapers.sites.doxbin
import doxscrapers.sites.chan
import doxscrapers.sites.skidpaste

SITES = {
    "pastebin": doxscrapers.sites.pastebin.PasteBinDoxScraper,
    "cloudnine": doxscrapers.sites.cloudnine.CloudNineDoxScraper,
    "kdepaste": doxscrapers.sites.kdepaste.KdePasteDoxScraper,
    "doxbin": doxscrapers.sites.doxbin.DoxBinDoxScraper,
    "fourchan-pol": doxscrapers.sites.chan.FourChanPolDoxScraper,
    "fourchan-b": doxscrapers.sites.chan.FourChanBDoxScraper,
    "eightchan-pol": doxscrapers.sites.chan.EightChanPolDoxScraper,
    "eightchan-baphomet": doxscrapers.sites.chan.EightChanBaphometDoxScraper,
    "skidpaste": doxscrapers.sites.skidpaste.SkidPasteDoxScraper,
}

PARSER = argparse.ArgumentParser(description="Scrape all posts on a post site "
                                             "and submit it to the marshling "
                                             "service")
PARSER.add_argument('-s', '--site', required=True, choices=SITES.keys(),
                    help="The dox hosting site to scrape.")
PARSER.add_argument('-m', '--marshaller', required=True,
                    help="The URL of the marshalling web server that "
                         "scaped data should be sent to. (ex 127.0.0.1:8080)")
PARSER.add_argument('-l', '--logdir', default=None,
                    help="The directory to write logging information to.")
PARSER.add_argument('-v', '--verbose', action="store_true",
                    help="Whether to print out verbose informational "
                         "messages to STDOUT")
PARSER.add_argument('-x', '--proxy', default=None, action='append',
                    help="If provided, should be a 'host[:port]' value to "
                         "use when accessing the pastebin API.  If multiple "
                         "values are provided, they'll be rotated through.")
ARGS = PARSER.parse_args()

GET_PROXY = doxscrapers.proxy.make_rotator(ARGS.proxy)
doxscrapers.reporting.configure_logger(ARGS.logdir, ARGS.verbose, ARGS.site)

SEEN_IDS = collections.deque([], 10000)
SCRAPER = SITES[ARGS.site](ARGS.marshaller)

while True:
    SCRAPER.throttle()
    ITEMS = SCRAPER.items_in_index(proxy=GET_PROXY())

    if ITEMS is None:
        continue

    for ITEM in ITEMS:
        ITEM_ID = ITEM.key
        if ITEM_ID is None:
            continue
        if ITEM_ID in SEEN_IDS:
            continue

        SCRAPER.throttle()
        ITEM_DETAILS = SCRAPER.details_for_item(ITEM)
        if ITEM_DETAILS is None:
            continue

        WAS_SUCCESSFUL = SCRAPER.submit(ITEM_DETAILS)
        if WAS_SUCCESSFUL:
            SEEN_IDS.append(ITEM_ID)

    SCRAPER.pause()
