#!/usr/bin/env python
import argparse
import os
import tornado.ioloop
import tornado.web
from tornado.log import gen_log
from doxclassifier.classifier import dox_classifier
import doxclassifier.controllers
import doxclassifier.reporting


CUR_DIR = os.path.dirname(os.path.abspath(__file__))

parser = argparse.ArgumentParser(description="Launches a webserver that "
                                             "classifies text as yes-no dox")
parser.add_argument("-d", "--dox", default=os.path.join(CUR_DIR, "data", "doxes"),
                    help="Path to a directory of files to treat as dox files "
                         "for training the classifier")
parser.add_argument("-n", "--false", default=os.path.join(CUR_DIR, "data", "not_doxes"),
                    help="Path to a directory of files to treat as not dox files "
                         "for training the classifier")
parser.add_argument('-p', '--port', default=8888, type=int,
                    help="The port the webserver should listen on.")
parser.add_argument('-i', '--ip', default="0.0.0.0",
                    help="The IP address to listen on.")
parser.add_argument('-l', '--log', default=None,
                    help="Path to write logs to.")
parser.add_argument('-v', '--verbose', action="store_true",
                    help="Enables debugging / verbose logging.")
ARGS = parser.parse_args()


true_examples = [("dox", os.path.join(ARGS.dox, fn)) for fn in os.listdir(ARGS.dox)]
false_examples = [("not", os.path.join(ARGS.false, fn)) for fn in os.listdir(ARGS.false)]

training_examples = true_examples + false_examples
training_labels, training_data = zip(*training_examples)

gen_log.info("Beginning training of classifier")
dox_predictor = dox_classifier(training_data, training_labels)

SETTINGS = {
    "debug": ARGS.verbose,
    "log_function": doxclassifier.reporting.http_error_logger,
}

application = tornado.web.Application([
    (r"/predict", doxclassifier.controllers.ClassifyHandler),
], debug=ARGS.verbose)

doxclassifier.controllers.set_dox_predictor(dox_predictor)
doxclassifier.reporting.configure_logger(ARGS.log, ARGS.verbose)

application.listen(ARGS.port, address=ARGS.ip)
tornado.ioloop.IOLoop.current().start()
