#!/usr/bin/env python

import argparse
import tornado.web
import doxmarshaller.controllers
import doxmarshaller.reporting


parser = argparse.ArgumentParser(description="Launches a webserver that "
                                             "takes in raw text files, and "
                                             "speaks to the other webservices "
                                             "in the pipeline to classify and "
                                             "extract dox information")
parser.add_argument('-c', '--classifier', required=True,
                    help="Domain and (optional) port to connect to the "
                         "classifier web service")
parser.add_argument('-d', '--dburl', required=True,
                    help="Domain and (optional) port to connect to the "
                         "database connector webservice")
parser.add_argument('-e', '--extractor', required=True,
                    help="Domain and (optional) port to connect to the "
                         "extractor webservice")
parser.add_argument('-s', '--social', required=True,
                    help="Domain and (optional) port to connect to the "
                         "social service scraper webservice")
parser.add_argument('-p', '--port', default=8888, type=int,
                    help="The port the webserver should listen on.")
parser.add_argument('-i', '--ip', default="0.0.0.0",
                    help="The IP address to listen on.")
parser.add_argument('-l', '--log', default=None,
                    help="Path to write logs to.")
parser.add_argument('-v', '--verbose', action="store_true",
                    help="Enables debugging / verbose logging.")
ARGS = parser.parse_args()


doxmarshaller.reporting.configure_logger(ARGS.log, ARGS.verbose)

system_urls = {
    "HAS_PASTE_BEEN_RECORDED_URL": "http://{}/does-paste-exist".format(ARGS.dburl),
    "RECORD_PASTE_URL": "http://{}/record-paste".format(ARGS.dburl),
    "RECORD_SOCIAL_ACCOUNT_URL": "http://{}/record-social-account".format(ARGS.dburl),
    "RECORD_SOCIAL_CRAWL_URL": "http://{}/record-crawl".format(ARGS.dburl),
    "CLASSIFY_TEXT_URL": "http://{}/predict".format(ARGS.classifier),
    "EXTRACT_TOKENS_URL": "http://{}/extract".format(ARGS.extractor),
    "SOCIAL_SCRAPE_URL": "http://{}/scrape".format(ARGS.social),
}

doxmarshaller.controllers.set_urls(system_urls)

SETTINGS = {
    "debug": ARGS.verbose,
    "log_function": doxmarshaller.reporting.http_error_logger,
}

APPLICATION = tornado.web.Application([
    (r'/record', doxmarshaller.controllers.ReceiveTextHandler)
], **SETTINGS)
APPLICATION.listen(ARGS.port, address=ARGS.ip)
tornado.ioloop.IOLoop.current().start()
